@@ -14,10 +14,12 @@ from __future__ import absolute_import, division, unicode_literals
 import time
 
 from mo_future import allocate_lock
-from mo_logs import Log
+from mo_imports import expect
 from mo_logs.log_usingNothing import StructuredLogger
 from mo_logs.strings import expand_template
 
+Log = expect("Log")
+
 
 class StructuredLogger_usingFile(StructuredLogger):
     def __init__(self, file):
